import {
  Body,
  Controller,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/core';
import { ApiResponse } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UserDTO, FetchDTO, FetchVO, UserUpdateDTO } from '../../interface';
import { UserService } from '../../service/user.service';
import { BaseController } from '../../util/BaseController';

@Controller('/test')
export class TestController extends BaseController {
  cla = 'test';

  async test() {
    console.log('test2');
  }
  @Inject()
  userService: UserService;

  @Get('/')
  async query(@Query('skip') skip: number, @Query('limit') limit: number) {
    const data = await this.userService.query({}, { skip, limit });
    const total = await this.userService.count({});
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({
    type: FetchVO,
  })
  async fetch(@Param('id') id: string) {
    const data = await this.userService.fetch(id);
    const result = new FetchVO(data);
    return result;
  }

  @Post('/')
  @Validate()
  async create(@Body() data: UserDTO) {
    const d2 = await this.userService.create(data);
    return d2;
  }
  @Post('/:id')
  async update(@Param('id') id: string, @Body() body: UserUpdateDTO) {
    const result = await this.userService.updateOne(id, body);
    return result;
  }
}
